PrivacyPolicyLocalization class
Localization configuration for PrivacyPolicyPage UI elements
Constructors
Properties
- acceptText → String
-
final
- continueText → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- privacyTitle → String
-
final
- rejectText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snackBarOpenLinkText → String
-
final
- termsTitle → String
-
final
- titleText → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getLocalization(
String locale, {String fallbackLocale = 'en'}) → PrivacyPolicyLocalization - Get localization for a specific locale with fallback support
Constants
-
builtInLocalizations
→ const Map<
String, PrivacyPolicyLocalization> - Built-in localizations for common languages